@@ -12,12 +12,18 @@ from ioc.requirement import DeclaredRequirement
 from ioc.requirement import NOT_PROVIDED
 from ioc.requirement import NO_DEFAULT
 from ioc.exc import UnsatisfiedDependency
+from ioc.exc import MissingDependencies
+from ioc.provider import get_unsatisfied_dependencies
 
 
 __version__ = '1.3.11'
 
 
 def require(names, *args, **kwargs):
+    req = provider.get_requirement(names)
+    if req is not None:
+        return req
+
     return DeclaredRequirement(provider, names, *args, **kwargs)
 
 
@@ -150,3 +156,12 @@ def call(name, *args, **kwargs):
     the given positional and keyword arguments.
     """
     pass
+
+
+def check():
+    """Inspect the provider and raise an exception if there are missing
+    dependencies.
+    """
+    missing = get_unsatisfied_dependencies()
+    if missing:
+        raise MissingDependencies(missing)
