@@ -4,4 +4,4 @@ import ioc
 
 def pytest_runtest_teardown(item, nextitem):
     """Tear down the inversion-of-control container after each test."""
-    ioc.teardowm()
+    ioc.teardown()
